<?php

/**
 * custom option and settings
 */
function wosmpl_settings_init() {
 // register a new setting for "wosmpl" page
 register_setting( 'wosmpl', 'wosmpl_options' );
 
 // register a new section in the "wosmpl" page
 add_settings_section(
     'wosmpl_section_map_page', //id
     __( 'Map Page', 'wosm' ), //title
     'wosmpl_section_map_page', //callback
     'wosmpl' //page slug
 );
 add_settings_section(
     'wosmpl_section_menu_page', //id
     __( 'Menu', 'wosm' ), //title
     'wosmpl_section_menu_page', //callback
     'wosmpl' //page slug
 );
 add_settings_section(
     'wosmpl_section_kohinos_page', //id
     __( 'Kohinos', 'wosm' ), //title
     'wosmpl_section_kohinos_page', //callback
     'wosmpl' //page slug
 );
 
 // register a new field in the "wosmpl_section_map_page" section, inside the "wosmpl" page
 add_settings_field(
     'wosmpl_map_page_id', // as of WP 4.6 this value is used only internally
     // use $args' label_for to populate the id inside the callback
     __( 'Main map page', 'wosmpl' ), //title
     'wosmpl_main_map_page_id', //callback
     'wosmpl', //page
     'wosmpl_section_map_page', //section and args above
     [
         'label_for' => 'wosmpl_main_map_page_id',
         'class' => 'wosmpl_row',
         'wosmpl_custom_data' => 'custom',
     ]
     );
 add_settings_field(
     'wosmpl_map_size_ref', // 
     __( 'Elt selector for map width', 'wosmpl' ), //title
     'wosmpl_main_map_size_ref', //callback
     'wosmpl', //page
     'wosmpl_section_map_page', //section and args above
     [
         'label_for' => 'wosmpl_main_map_size_ref',
         'class' => 'wosmpl_row'
     ]
     );
 add_settings_field(
     'wosmpl_map_cat_legend', // 
     __( 'Cat. legend', 'wosmpl' ), //title
     'wosmpl_main_map_legend', //callback
     'wosmpl', //page
     'wosmpl_section_map_page', //section and args above
     [
         'label_for' => 'wosmpl_main_map_cat_legend',
         'class' => 'wosmpl_row'
     ]
     );
 
 add_settings_field(
     'wosmpl_partner_menu', // 
     __( 'Show sub-menu', 'wosmpl' ), //title
     'wosmpl_partner_menu_show', //callback
     'wosmpl', //page
     'wosmpl_section_menu_page', //section and args above
     [
         'label_for' => 'wosmpl_partner_sub_menu_show',
         'class' => 'wosmpl_row'
     ]
     );
  add_settings_field(
     'wosmpl_kohinos_url', // 
     __( 'Server url', 'wosmpl' ), //title
     'wosmpl_kohinos_url', //callback
     'wosmpl', //page
     'wosmpl_section_kohinos_page', //section and args above
     [
         'label_for' => 'wosmpl_kohinos_url',
         'class' => 'wosmpl_row'
     ]
     );
  add_settings_field(
     'wosmpl_kohinos_api_key', // 
     __( 'API key', 'wosmpl' ), //title
     'wosmpl_kohinos_api_key', //callback
     'wosmpl', //page
     'wosmpl_section_kohinos_page', //section and args above
     [
         'label_for' => 'wosmpl_kohinos_api_key',
         'class' => 'wosmpl_row'
     ]
     );
}




add_action( 'admin_init', 'wosmpl_settings_init' );

function wosmpl_section_map_page( $args ) {
 ?>
 <p id="<?php echo esc_attr( $args['id'] ); ?>"><?php esc_html_e( 'Main Map settings', 'wosmpl' ); ?></p>
 <?php
}
function wosmpl_section_menu_page( $args ) {
 ?>
 <p id="<?php echo esc_attr( $args['id'] ); ?>"><?php esc_html_e( 'Partner menu dispay', 'wosmpl' ); ?></p>
 <?php   
}
function wosmpl_section_kohinos_page( $args ) {
 ?>
 <p id="<?php echo esc_attr( $args['id'] ); ?>"><?php esc_html_e( 'Kohinos params.', 'wosmpl' ); ?></p>
 <?php   
}
// field callbacks can accept an $args parameter, which is an array.
// $args is defined at the add_settings_field() function.
// wordpress has magic interaction with the following keys: label_for, class.
// the "label_for" key value is used for the "for" attribute of the <label>.
// the "class" key value is used for the "class" attribute of the <tr> containing the field.
// you can add custom key value pairs to be used inside your callbacks.
function wosmpl_main_map_page_id( $args ) {
 // get the value of the setting we've registered with register_setting()
 $options = get_option( 'wosmpl_options' );
 // output the field
 $candidate_pages = wosmpl_pages_with_shortcode('wosmpl_map');
 ?>
 <select id="<?php echo esc_attr( $args['label_for'] ); ?>"
  name="wosmpl_options[<?php echo esc_attr( $args['label_for'] ); ?>]"
 >
 <option value="0" <?php echo isset( $options[ $args['label_for'] ] ) ? ( selected( $options[ $args['label_for'] ], '0', false ) ) : ( '' ); ?>>
 <?php esc_html_e( 'Select', 'wosmpl' ); ?>
 </option>
  <?php 
        foreach ($candidate_pages as $p) {
          echo '<option value="'.$p->ID.'" '.selected($options[ $args['label_for'] ],$p->ID).'>'.$p->post_title.'</option>';
          }
  ?>
 </select>
  
 <?php
}

function wosmpl_main_map_size_ref( $args ) {
    $options = get_option( 'wosmpl_options' );
    echo '<input name="wosmpl_options['.esc_attr( $args['label_for'] ).']"';
    echo ' value="'.$options[ $args['label_for'] ].'" />';
}

function wosmpl_main_map_legend($args) {
    $options = get_option( 'wosmpl_options' );
    echo '<input maxlength="256" name="wosmpl_options['.esc_attr( $args['label_for'] ).']" value="'.$options[ $args['label_for'] ].'" style="min-width:75em;" />';
}

function wosmpl_partner_menu_show($args) {
    $value = get_option( 'wosmpl_options' )[$args['label_for']] ?? '';
    $checked = ($value === 'yes') ? ' checked="checked"' : '';
    echo '<input name="wosmpl_options['.esc_attr( $args['label_for'] ).']" type="checkbox" value="yes" '.$checked.' />';
}

function wosmpl_kohinos_url( $args ) {
    $options = get_option( 'wosmpl_options' );
    echo '<input name="wosmpl_options['.esc_attr( $args['label_for'] ).']"';
    echo ' value="'.$options[ $args['label_for'] ].'" style="min-width:75em;" />';
}

function wosmpl_kohinos_api_key( $args ) {
    $options = get_option( 'wosmpl_options' );
    echo '<input name="wosmpl_options['.esc_attr( $args['label_for'] ).']"';
    echo ' value="'.$options[ $args['label_for'] ].'"  style="min-width:75em;" />';
}


function wosmpl_options_page_html()
{
    // check user capabilities
    if (!current_user_can('manage_options')) {
        return;
    }
    // add error/update messages
 
     // check if the user have submitted the settings
     // wordpress will add the "settings-updated" $_GET parameter to the url
     if ( isset( $_GET['settings-updated'] ) ) {
         // add settings saved message with the class of "updated"
         add_settings_error( 'wosmpl_messages', 'wosmpl_message', __( 'Settings Saved', 'wosmpl' ), 'updated' );
     }
     
     // show error/update messages
     settings_errors( 'wosmpl_messages' );
    ?>
    <div class="wrap">
        <h1><?= esc_html(get_admin_page_title()); ?></h1>
        <form action="options.php" method="post">
            <?php
            // output security fields for the registered setting "wosmpl_options"
            settings_fields('wosmpl');
            // output setting sections and their fields
            // (sections are registered for "wospml", each field is registered to a specific section)
            do_settings_sections('wosmpl');
            // output save settings button
            submit_button('Save Settings');
            ?>
        </form>
    </div>
    <?php
}

